/* jshint globalstrict:true */
'use strict';

const SIZES_CONTAINER_ID = 'locrmaps-sizes';

/**
 * These adjustments are necessary, because WooCommerce normalizes the size format from for example:
 * '21x29.7cm@150dpi' to '21x29-7cm150dpi'.
 * @param {string} value
 * @returns {string}
 */
function adjustCustomizedSizeValue(value) {
    return value.replaceAll('-', '.').replace(/([a-z])(\d+dpi)/, '$1@$2');
}

document.addEventListener('DOMContentLoaded', function() {
    let sizesElement;

    const locrmapsSizesQuerySelector = document.getElementById('locrmaps-sizes-query-selector');
    if (locrmapsSizesQuerySelector instanceof HTMLInputElement && locrmapsSizesQuerySelector.value) {
        sizesElement = document.querySelector(locrmapsSizesQuerySelector.value);
    }
    if (!sizesElement) {
        sizesElement = document.getElementById(SIZES_CONTAINER_ID);
    }
    if (!sizesElement) {
        sizesElement = document.querySelector('select#size');
    }
    if (!sizesElement) {
        sizesElement = document.querySelector('select#pa_size');
    }

    if (sizesElement instanceof HTMLSelectElement) {
        if (sizesElement.value) {
            document.dispatchEvent(new CustomEvent('locr.locrmaps.set-print-format', { detail: { printFormatString: adjustCustomizedSizeValue(sizesElement.value) } }));

            if (wp?.hooks) {
                wp.hooks.addAction(
                    'locrMAPSInitialized',
                    'locr/locrmaps',
                    () => document.dispatchEvent(new CustomEvent('locr.locrmaps.set-print-format', { detail: { printFormatString: adjustCustomizedSizeValue(sizesElement.value) } }))
                );
            }
        }

        sizesElement.addEventListener('change', function(event) {
            if (!(event.target instanceof HTMLSelectElement)) {
                return;
            }

            document.dispatchEvent(new CustomEvent('locr.locrmaps.set-print-format', { detail: { printFormatString: adjustCustomizedSizeValue(event.target.value) } }));
        });
    }
});
